=== modified file 'tests/unit/test-place.vala'
--- tests/unit/test-place.vala	2010-06-04 09:36:28 +0000
+++ tests/unit/test-place.vala	2010-06-04 10:10:38 +0000
@@ -33,6 +33,8 @@
                           PlaceSuite.test_one_entry);
       Test.add_data_func ("/Unit/Place/TwoEntries",
                           PlaceSuite.test_two_entries);
+      Test.add_data_func ("/Unit/Place/LocalModels",
+                          PlaceSuite.test_local_models);
     }
 
     internal static void test_empty_controller()
@@ -129,5 +131,38 @@
       entries = ctl.get_entries ();
       assert (entries.length == 0);
     }
+  
+    internal static void test_local_models ()
+    {
+      var entry = new EntryInfo("/foo/bar");
+      Dee.Model sections_model = new Dee.SequenceModel(2,
+                                                       typeof(string),
+                                                       typeof(string));
+      entry.sections_model = sections_model;
+      assert (entry.sections_model == sections_model);
+      assert (sections_model.get_n_rows() == 0);
+      
+      var renderer = entry.entry_renderer_info;
+      assert (renderer is RendererInfo);
+      Dee.Model groups_model = new Dee.SequenceModel(3,
+                                                     typeof(string),
+                                                     typeof(string),
+                                                     typeof(string));
+      renderer.groups_model = groups_model;
+      assert (renderer.groups_model == groups_model);
+      assert (groups_model.get_n_rows() == 0);
+
+      Dee.Model results_model = new Dee.SequenceModel(6,
+                                                      typeof(string),
+                                                      typeof(string),
+                                                      typeof(uint),
+                                                      typeof(string),
+                                                      typeof(string),
+                                                      typeof(string));
+      renderer.results_model = results_model;
+      assert (renderer.results_model == results_model);
+      assert (results_model.get_n_rows() == 0);
+    }
+    
   }
 }

=== modified file 'unity/unity-place.vala'
--- unity/unity-place.vala	2010-06-04 09:19:54 +0000
+++ unity/unity-place.vala	2010-06-04 10:10:38 +0000
@@ -16,6 +16,25 @@
  * Authored by Mikkel Kamstrup Erlandsen <mikkel.kamstrup@canonical.com>
  *
  */
+
+/*
+ * IMPLEMENTATION NOTE:
+ * It may appear this code it is bit more bloated than it needs to be
+ * (considering the pure number of classes and indirections), but this has
+ * some good reasons.
+ *
+ * Firstly we want to hide away Vala's internal DBus marshalling which would
+ * expose raw structs in the. These structs are hidden away in _RendererInfo,
+ * and _EntryInfo. We wrap these in handy GObjects with properties and what not.
+ * In fact we want to hide all DBusisms, which is also why the DBus interfaces
+ * are declared private.
+ *
+ * Secondly we want the generatedd C API to be nice and not too Vala-ish. We
+ * must anticipate that place daemons consuming libunity will be written in
+ * both Vala and C.
+ *
+ */
+
 using Dee;
 using DBus;
 

=== modified file 'vapi/dee-1.0.vapi'
--- vapi/dee-1.0.vapi	2010-06-03 10:22:01 +0000
+++ vapi/dee-1.0.vapi	2010-06-04 10:10:38 +0000
@@ -52,7 +52,7 @@
 	[CCode (cheader_filename = "dee.h")]
 	public class SequenceModel : Dee.VersionedModel, Dee.Model {
 		[CCode (type = "DeeModel*", has_construct_function = false)]
-		public SequenceModel (uint n_columns);
+		public SequenceModel (uint n_columns, ...);
 	}
 	[CCode (cheader_filename = "dee.h")]
 	public class SharedModel : Dee.ProxyModel, Dee.Model {

